# Hidra/HTTP/ZMQ/NeXus Image Source Settings

Created by Jan Kotanski, last modified on Jan 10, 2020 11:44

The third tab of the configuration dialog contains Image Sources configuration. It allows for the user to adjust image sources and their dialogs.

Hidra:

- Source timeout in ms: maximal time for waiting for a new image in one call
- Detector servers: possible list of hidra detector hosts separated by spaces
- Data port: hidra data port. Each instance of lavue on the same host should use a different data port
- Use default detector servers: add default detector server names from the DESY pool

HTTP response

- URLs: JSON dictionary assigning labels to HTTP urls

ZMQ Stream

- Servers and Ports: JSON dictionary assigning labels to server and port of ZMQ stream
- Automatic datasources: selects possible datasources from ZMQ stream metadata
- Datasources: defines possible datasources, i.e. ZMQ topics, separated by spaces

Nexus File

- Keep the file open: does not close the nexus file after reading the field frame
- Start from the last image: displays only the last image frame